<?php
/* $Id: arabic-utf-8.inc.php,v 2.78 2005/07/29 17:03:05 lem9 Exp $ */

/**
 * Original translation to Arabic by Fisal <fisal77 at hotmail.com>
 * Update by Tarik kallida <kallida at caramail.com>
 * Final Update on November 25, 2003 by Ossama Khayat <okhayat at yahoo.com>
 */

$charset = 'utf-8';
$allow_recoding = TRUE;
$text_dir = 'rtl'; // ('ltr' for left to right, 'rtl' for right to left)
$left_font_family = 'Tahoma, verdana, arial, helvetica, sans-serif';
$right_font_family = '"Windows UI", Tahoma, verdana, arial, helvetica, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
//$byteUnits = array('بايت', 'كيلوبايت', 'ميجابايت', 'غيغابايت');
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('الأحد', 'الإثنين', 'الثلاثاء', 'الأربعاء', 'الخميس', 'الجمعة', 'السبت');
$month = array('يناير', 'فبراير', 'مارس', 'أبريل', 'مايو', 'يونيو', 'يوليو', 'أغسطس', 'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d %B %Y الساعة %H:%M';

$timespanfmt = '%s يوم، %s ساعة، %s دقيقة و%s ثانية';

$strAPrimaryKey = 'لقد أُضيف المفتاح الأساسي في %s';
$strAbortedClients = 'ألغي';
$strAbsolutePathToDocSqlDir = 'الرجاء كتابة المسار المطلق على خادم الشبكة إلى دليل docSQL';
$strAccessDenied = 'غير مسموح';
$strAccessDeniedExplanation = 'حاول phpMyAdmin الاتصال بخادم MySQL، ورفض الخادم الاتصال. عليك أن تتحقق من المستضيف، أو اسم المستخدم وكلمة المرور في ملف الإعداد config.inc.php وتتأكد أنها مطابقة للمعلومات المعطاة إليك من قبل المسؤول عن خادم MySQL.';
$strAction = 'العملية';
$strAddAutoIncrement = 'أضف قيمة AUTO_INCREMENT';
$strAddConstraints = 'أضف قيوداً';
$strAddDeleteColumn = 'إضافه/حذف عمود حقل';
$strAddDeleteRow = 'إضافه/حذف صف سجل';
$strAddDropDatabase = 'أضف أو احذف قاعدة بيانات';
$strAddIntoComments = 'أضف إلى الملاحظات';
$strAddNewField = 'إضافة حقل جديد';
$strAddPrivilegesOnDb = 'إضافة الصلاحيات على قاعدة البيانات التالية';
$strAddPrivilegesOnTbl = 'إضافة الصلاحيات على الجدول التالي';
$strAddSearchConditions = 'أضف شروط البحث (جسم من الفقره "where" clause):';
$strAddToIndex = 'إضافه كفهرس &nbsp;%s&nbsp;صف(ـوف)';
$strAddUser = 'أضف مستخدم جديد';
$strAddUserMessage = 'لقد أضفت مستخدم جديد.';
$strAddedColumnComment = 'تم إضافة التعليق للعمود';
$strAddedColumnRelation = 'تم إضافة العلاقة للعمود';
$strAdministration = 'إدارة';
$strAffectedRows = 'صفوف مؤثره:';
$strAfter = 'بعد %s';
$strAfterInsertBack = 'الرجوع إلى الصفحة السابقة';
$strAfterInsertNewInsert = 'إدخال تسجيل جديد';
$strAll = 'الكل';
$strAllTableSameWidth = 'أظهر كل الجدوال بنفس العرض؟';
$strAlterOrderBy = 'تعديل ترتيب الجدول بـ';
$strAnIndex = 'لقد أُضيف الفهرس في %s';
$strAnalyzeTable = 'تحليل الجدول';
$strAnd = 'و';
$strAny = 'أي';
$strAnyHost = 'أي مزود';
$strAnyUser = 'أي مستخدم';
$strArabic = 'العربية';
$strArmenian = 'الأرمنية';
$strAscending = 'تصاعدياً';
$strAtBeginningOfTable = 'في بداية الجدول';
$strAtEndOfTable = 'في نهاية الجدول';
$strAttr = 'الخواص';
$strAutodetect = 'التفحص التلقائي';
$strAutomaticLayout = 'مظهر تلقائي';

$strBack = 'رجوع';
$strBaltic = 'البلطيق';
$strBeginCut = 'بدء القصّ';
$strBeginRaw = 'بدء بيانات أصليّة';
$strBinary = 'ثنائي';
$strBinaryDoNotEdit = 'ثنائي - لاتحرره';
$strBookmarkAllUsers = 'اسمح لكل المستخدمين الوصول إلى هذه العلامة المرجعية';
$strBookmarkDeleted = 'لقد حُذفت العلامه المرجعيه.';
$strBookmarkLabel = 'علامه';
$strBookmarkOptions = 'خيارات العلامات';
$strBookmarkQuery = 'علامه مرجعيه SQL-إستعلام';
$strBookmarkThis = 'إجعل علامه مرجعيه SQL-إستعلام';
$strBookmarkView = 'عرض فقط';
$strBrowse = 'إستعراض';
$strBrowseForeignValues = 'استعرض القيم الغريبة';
$strBulgarian = 'البلغارية';
$strBzError = 'لم يستطع phpMyAdmin ضغط كمّ البيانات بسبب عطل في امتداد Bz2 في إصدار PHP. يُفضّل أن تغيّر قيمة توجيه <code>$cfg[\'BZipDump\']</code> في ملف إعدادات phpMyAdmin إلى <code>FALSE</code>. إن كنت تريد استخدام مزايا ضغط Bz2، عليك بالتحديث إلى إصدار جديد من PHP. لمزيد من التفاصيل، أنظر في تقرير خلل PHP %s.';
$strBzip = '"bzipped"';

$strCSVOptions = 'خيارات القيم المفصولة بفواصل )CSV(';
$strCannotLogin = 'لا يمكن الدخول إلى خادم MySQL';
$strCantLoad = 'لا يمكن قراءة الامتداد %s،<br />رجاء تأكد من إعدادات PHP.';
$strCantLoadRecodeIconv = 'لم يمكن تحميل iconv أو إعادة تشفير الإمتداد المطلوب لتحويل شيفرة الأحرف، الرجاء إعداد PHP ليسمح باستخدام هذه الإمتدادات أو عطل عمل التحويل في phpMyAdmin.';
$strCantRenameIdxToPrimary = 'لايمكن تغيير إسم الفهرس إلى الأساسي!';
$strCantUseRecodeIconv = 'لا يمكن استخدام iconv ولا libiconv ولا عملية recode_string في حين يحدد الامتداد أنه محمّل. تأكّد من إعدادات PHP.';
$strCardinality = 'Cardinality';
$strCarriage = 'إرجاع الحموله: \\r';
$strCaseInsensitive = 'غير حساس لحالة الأحرف';
$strCaseSensitive = 'حساس لحالة الأحرف';
$strCentralEuropean = 'أوروبا الوسطى';
$strChange = 'تغيير';
$strChangeCopyMode = 'أضف اسم مستخدم جديد بنفس الصلاحيات و...';
$strChangeCopyModeCopy = ' ... أبق القديم.';
$strChangeCopyModeDeleteAndReload = ' ... إحذف القديمين من جداول المستخدمين وأعد قراءة الصلاحيات بعد ذلك.';
$strChangeCopyModeJustDelete = ' ... إحذف القديم من جداول المستخدمين.';
$strChangeCopyModeRevoke = ' ... استعد كل الصلاحيات الفعالة من القديمين واحذهم بعد ذلك.';
$strChangeCopyUser = 'غيّر معلومات الدخول / إنسخ اسم مستخدم';
$strChangeDisplay = 'اختر الحقل لإظهاره';
$strChangePassword = 'تغيير كلمة السر';
$strCharset = 'مجموعة المحارف';
$strCharsetOfFile = 'شيفرة أحرف الملف:';
$strCharsets = 'مجموعات المحارف';
$strCharsetsAndCollations = 'مجموعات المحارف وCollations';
$strCheckAll = 'إختر الكل';
$strCheckOverhead = 'تحقق من overhead';
$strCheckPrivs = 'تحقق من الصلاحيات';
$strCheckPrivsLong = 'تحقق من الصلاحيات لقاعدة بيانات &quot;%s&quot;.';
$strCheckTable = 'التحقق من الجدول';
$strChoosePage = 'رجاءً اختر صفحة لتعديلها';
$strColComFeat = 'إظهار تعليقات العمود';
$strCollation = 'Collation';
$strColumnNames = 'إسم العمود';
$strColumnPrivileges = 'صلاحيات خاصة بالحقل';
$strCommand = 'أمْر';
$strComments = 'تعليقات';
$strCompleteInserts = 'الإدخال لقد إكتمل';
$strCompression = 'الضغط';
$strConfigFileError = 'لم يستطع phpMyAdmin أن يقرأ ملف إعداداتك!<br />قد يكون هذا بسبب أن PHP وجد خطأ في الإعراب فيه أو أنه لا يستطيع أن يجد الملف.<br />رجاءً اقرأ الملف بشكل مباشر باستخدام الوصلة أدناه واقرأ رسالة الخطأ الناتجة. في معظم الحالات قد تكون علامة التنصيص أو علامة الفاصلة المنقوطة ناقصة في مكان ما.<br />إن حصلت على صفحة فارغة، فكلّ شيء على ما يرام.';
$strConfigureTableCoord = 'رجاء إعداد الموقع للجدول %s';
$strConnections = 'اتصالات';
$strConstraintsForDumped = 'قيود الجداول المحفوظة';
$strConstraintsForTable = 'القيود للجدول';
$strCookiesRequired = 'يجب تفعيل دعم الكوكيز في هذه المرحلة.';
$strCopyTable = 'نسخ الجدول إلى';
$strCopyTableOK = 'الجدول %s لقد تم نسخه إلى %s.';
$strCopyTableSameNames = 'لا يمكن نسخ الجدول إلى نفسه!';
$strCouldNotKill = 'لم يستطع phpMyAdmin إيقاف العمليّة %s. يبدو أنها أوقفت مسبقاً.';
$strCreate = 'تكوين';
$strCreateIndex = 'تصميم فهرسه على&nbsp;%s&nbsp;عمود';
$strCreateIndexTopic = 'تصميم فهرسه جديده';
$strCreateNewDatabase = 'تكوين قاعدة بيانات جديدة';
$strCreateNewTable = 'تكوين جدول جديد في قاعدة البيانات %s';
$strCreatePage = 'أنشئ صفحة جديدة';
$strCreatePdfFeat = 'إنشاء ملفات PDF';
$strCreationDates = 'تواريخ الإنشاء/التحديث/التحقّق';
$strCriteria = 'المعايير';
$strCroatian = 'الكرواتية';
$strCyrillic = 'السيريلية';
$strCzech = 'التشيكية';

$strDBComment = 'ملاحظة قاعدة البيانات: ';
$strDBGContext = 'السياق';
$strDBGContextID = 'رقم السياق';
$strDBGHits = 'استخدامات';
$strDBGLine = 'سطر';
$strDBGMaxTimeMs = 'أقصى وقت، مث';
$strDBGMinTimeMs = 'أقل وقت، مث';
$strDBGModule = 'وِحْدة';
$strDBGTimePerHitMs = 'وقت/استخدام، مث';
$strDBGTotalTimeMs = 'الوقت الكلي، مث';
$strDanish = 'الدنمركية';
$strData = 'بيانات';
$strDataDict = 'قاموس البيانات';
$strDataOnly = 'بيانات فقط';
$strDatabase = 'قاعدة البيانات';
$strDatabaseExportOptions = 'خيارات تصدير قاعدة بيانات';
$strDatabaseHasBeenDropped = 'قاعدة بيانات %s محذوفه.';
$strDatabaseNoTable = 'لا تحتوي قاعدة البيانات هذه على جداول!';
$strDatabases = 'قاعدة بيانات';
$strDatabasesDropped = 'تم حذف قواعد البيانات %s بنجاح.';
$strDatabasesStats = 'إحصائيات قواعد البيانات';
$strDatabasesStatsDisable = 'أوقف الإحصائيات';
$strDatabasesStatsEnable = 'مكّن الإحصائيات';
$strDatabasesStatsHeavyTraffic = 'ملاحظة: تمكين إحصائيات قواعد البيانات هنا قد يسبب تدفق بيانات ثقيل بين خادم الوب وخادم MySQL.';
$strDbPrivileges = 'صلاحيات خاصة بقاعدة البيانات';
$strDbSpecific = 'خاص بقاعدة بيانات';
$strDefault = 'إفتراضي';
$strDefaultValueHelp = 'للقيم الافتراضية، الرجاء أدخل قيمة مفردة، دون علامات هروب أو تنصيص، باستخدام التنسيق: a';
$strDelOld = 'تحتوي الصفحة الحالية مراجع لجداول لم تعد موجودة. هل تود حذف هذه المراجع؟';
$strDelayedInserts = 'استخدم الإضافات المتأخرة';
$strDelete = 'حذف';
$strDeleteAndFlush = 'احذف المستخدمين وقم بإعادة قراءة الصلاحيات بعد ذلك.';
$strDeleteAndFlushDescr = 'هذه هي أنظف طريقة، لكن إعادة قراءة الصلاحيات قد يتطلّب بعض الوقت.';
$strDeleted = 'لقد تم حذف الصف';
$strDeletedRows = 'الصفوف المحذوفه:';
$strDeleting = 'قيْد حذْف %s';
$strDescending = 'تنازلياً';
$strDescription = 'الوصف';
$strDictionary = 'قاموس';
$strDisabled = 'معطّل';
$strDisplayFeat = 'إظهار المزايا';
$strDisplayOrder = 'ترتيب العرض:';
$strDisplayPDF = 'إظهار بناء ملف PDF';
$strDoAQuery = 'تجعل "إستعلام بواسطة المثال" (wildcard: "%")';
$strDoYouReally = 'هل تريد حقاً تنفيذ';
$strDocu = 'مستندات وثائقيه';
$strDrop = 'حذف';
$strDropSelectedDatabases = 'إحذف قواعد البيانات المحددة';
$strDropUsersDb = 'إحذف قواعد البيانات التي لها نفس إسماء المستخدمين.';
$strDumpSaved = 'تم حفظ الـDump إلى الملف %s.';
$strDumpXRows = 'إحدف %s سطر بدءً من السطر %s.';
$strDumpingData = 'إرجاع أو إستيراد بيانات الجدول';
$strDynamic = 'ديناميكي';

$strEdit = 'تحرير';
$strEditPDFPages = 'عدّل صفحات PDF';
$strEditPrivileges = 'تحرير الإمتيازات';
$strEffective = 'فعال';
$strEmpty = 'إفراغ محتوى';
$strEmptyResultSet = 'MySQL قام بإرجاع نتيجة إعداد فارغه (مثلاً. صف صفري).';
$strEnabled = 'ممكّن';
$strEnd = 'نهايه';
$strEndCut = 'انتهاء القصّ';
$strEndRaw = 'انتهاء البيانات الأصلية';
$strEnglish = 'الإنجليزية';
$strEnglishPrivileges = ' ملاحظه: إسم الإمتياز لـMySQL يظهر ويُقرأ باللغه الإنجليزيه فقط ';
$strError = 'خطأ';
$strEstonian = 'الإستونية';
$strExcelEdition = 'إصدارة إكسل';
$strExcelOptions = 'خيارات إكسل';
$strExecuteBookmarked = 'نفّذ استعلام محفوظ بعلامة مرجعية';
$strExplain = 'إشرح SQL';
$strExport = 'تصدير';
$strExtendedInserts = 'إدخال مُدد';
$strExtra = 'إضافي';

$strFailedAttempts = 'محاولات أخفقت';
$strField = 'الحقل';
$strFieldHasBeenDropped = 'حقل محذوف %s';
$strFields = ' عدد الحقول';
$strFieldsEmpty = ' تعداد الحقل فارغ! ';
$strFieldsEnclosedBy = 'حقل مضمن بـ';
$strFieldsEscapedBy = 'حقل مُتجاهل بـ';
$strFieldsTerminatedBy = 'حقل مفصول بـ';
$strFileAlreadyExists = 'المف %s موجود اصلاً على الخادم. غير الاسم أو حدد خيار التسجيل على الملف الموجود.';
$strFileCouldNotBeRead = 'لم يمكن قراءة الملف';
$strFileNameTemplate = 'قالب إسم الملف';
$strFileNameTemplateHelp = 'استخدم __DB__ لإسم قاعدة البيانات، __TABLE__ لإسم الجدول و %sany strftime%s لخيارات تحديد الوقت، وسوف يتم إضافة الامتداد. سوف يتم الاحتفاظ بأي نص آخر.';
$strFileNameTemplateRemember = 'تذكر القالب';
$strFixed = 'مثبت';
$strFlushPrivilegesNote = 'ملاحظة: يقرأ phpMyAdmin صلاحيات المستخدمين من جداول الصلاحيات من خادم MySQL مباشرةً. محتويات هذه الجداول قد تختلف عن الصلاحيات التي يستخدمها الخادم إذا ما تمّ التعديل عليها يدويّاً. في هذه الحالة، عليك %s بإعادة قراءة الصلاحيات %s قبل أن تكمل.';
$strFlushTable = 'إعادة تحميل الجدول ("FLUSH")';
$strFormEmpty = 'يوجد قيمه مفقوده بالنموذج !';
$strFormat = 'صيغه';
$strFullText = 'نصوص كامله';
$strFunction = 'دالة';

$strGenBy = 'أنشئ بواسطة';
$strGenTime = 'أنشئ في';
$strGeneralRelationFeat = 'المزايا العامّة للرابط';
$strGerman = 'الألمانية';
$strGlobal = 'عامّ';
$strGlobalPrivileges = 'صلاحيّات عامّة';
$strGlobalValue = 'قيمة عامّة';
$strGo = '&nbsp;تنفيــذ&nbsp;';
$strGrantOption = 'مَنْحْ';
$strGreek = 'اليونانية';
$strGzip = '"gzipped"';

$strHasBeenAltered = 'لقد عُدِل.';
$strHasBeenCreated = 'لقد تكون.';
$strHaveToShow = 'عليك اختيار عمود واحد على الأقل للعرض';
$strHebrew = 'العبرية';
$strHome = 'الصفحة الرئيسية';
$strHomepageOfficial = 'الصفحة الرئيسية الرسمية لـ phpMyAdmin';
$strHost = 'المزود';
$strHostEmpty = 'إسم المستضيف فارغ!';
$strHungarian = 'الهنغارية';

$strId = 'رقم';
$strIdxFulltext = 'النص كاملاً';
$strIfYouWish = 'إذا كنت ترغب في أن تحمل بعض أعمدة الجدول فقط, حدد بالفاصله التي تفصل قائمة الحقل.';
$strIgnore = 'تجاهل';
$strIgnoringFile = 'تجاهل الملف %s';
$strImportDocSQL = 'استيراد ملفات docSQL';
$strImportFiles = 'استورد الملفات';
$strImportFinished = 'إنتهى الإستيراد';
$strInUse = 'قيد الإستعمال';
$strIndex = 'فهرست';
$strIndexHasBeenDropped = 'فهرسه محذوفه %s';
$strIndexName = 'إسم الفهرس&nbsp;:';
$strIndexType = 'نوع الفهرس&nbsp;:';
$strIndexes = 'فهارس';
$strInnodbStat = 'وضع InnoDB';
$strInsecureMySQL = 'يحتوي ملف الإعدادت الخاص بك تعيينات )المستخدم root دون كلمة مرور( والذي يشير إلى حساب المستخدم الرئيسي لـMySQL. خادم MySQL الذي يعمل بهذه الإعدادت الافتراضية معرض لخطر الاقتحام، وعليك أن تقوم بإصلاح ثغرة الأمان هذه في أقرب وقت ممكن.';
$strInsert = 'إدخال';
$strInsertAsNewRow = 'إدخال كتسجيل جديد';
$strInsertNewRow = 'إضافة تسجيل جديد';
$strInsertTextfiles = 'إدخال ملف نصي في الجدول';
$strInsertedRowId = 'رقم معرّف السّطر المضاف:';
$strInsertedRows = 'صفوف مدخله:';
$strInstructions = 'الأوامر';
$strInternalNotNecessary = '* العلاقة الداخلية غير ضرورية عندما تكون موجودة مسبقاً في InnoDB.';
$strInternalRelations = 'العلاقات الداخلية';

$strJapanese = 'اليابانية';
$strJumpToDB = 'إذهب إلى قاعدة بيانات &quot;%s&quot;.';
$strJustDelete = 'فقط قم بحذف المستخدمين من جدول الصلاحيات.';
$strJustDeleteDescr = 'سوف يبقى المستخدمون &quot;المحذوفون&quot; قادرون على الوصول للخادم كالعادة حتى يتم إعادة قراءة الصلاحيات.';

$strKeepPass = 'لاتغير كلمة السر';
$strKeyname = 'إسم المفتاح';
$strKill = 'إبطال';
$strKorean = 'الكورية';

$strLaTeX = 'لاتِكْسْ';
$strLaTeXOptions = 'خيارات لاتكس';
$strLandscape = 'عرض الصفحة';
$strLatexCaption = 'عنوان الجدول';
$strLatexContent = 'محتوييات الجدول __TABLE__';
$strLatexContinued = '(تابع)';
$strLatexContinuedCaption = 'عنوان جدول تابع';
$strLatexIncludeCaption = 'أضف عنواناً للجدول';
$strLatexLabel = 'Label key';
$strLatexStructure = 'بنية الجدول __TABLE__';
$strLengthSet = 'الطول/القيمه*';
$strLimitNumRows = 'رقم السجلات لكل صفحه';
$strLineFeed = 'خطوط معرفه: \\n';
$strLinesTerminatedBy = 'خطوط مفصوله بـ';
$strLinkNotFound = 'لم يمكن إيجاد الوصلة';
$strLinksTo = 'مرتبط بـ';
$strLithuanian = 'الليتوانية';
$strLoadExplanation = 'أفضل طريقة محددة بشكل افتراضي، إلا أنه يمكنك تغييرها إن لم تنجح.';
$strLoadMethod = 'طريق LOAD';
$strLocalhost = 'محلي';
$strLocationTextfile = 'مكان ملف نصي';
$strLogPassword = 'كلمة السر:';
$strLogServer = 'خادم السجلّ';
$strLogUsername = 'إسم المُستخدم:';
$strLogin = 'دخول';
$strLoginInformation = 'بيانات الدخول';
$strLogout = 'تسجيل خروج';

$strMIME_MIMEtype = 'نوع MIME';
$strMIME_available_mime = 'أنواع MIME المتوفرة';
$strMIME_available_transform = 'التحويلات المتوفرة';
$strMIME_description = 'الوصف';
$strMIME_nodescription = 'ليس هناك وصف متوفر لهذا التحويل.<br />رجاء اسأل الناشر، ما يفعله %s.';
$strMIME_transformation = 'تحويل المتصفح';
$strMIME_transformation_note = 'لعرض قائمة بخيارات التحويل المتوفرة وأنواع تحويلات MIME الخاصة بها، إضغط على %sخيارات التحويل%s';
$strMIME_transformation_options = 'خيارات التحويل';
$strMIME_transformation_options_note = 'رجاءً أدخل القيم لخيارات التحويل باستخدام هذا التنسيق: \'a\',\'b\',\'c\'...<br />إذا احتجت أن تضع شرْطة مائلة ("\") أو علامة تنصيص ("\'") بين هذه القيم، اسبقها بشرْطة مائلة )على سبيل المثال \'\\\\xyz\' أو \'a\\\'b\'(.';
$strMIME_without = 'أنواع MIME التي تظهر بحروف مائلة ليس لها وظيفة تحويل منفصلة';
$strModifications = 'تمت التعديلات';
$strModify = 'تعديل';
$strModifyIndexTopic = 'تعديل الفهرسه';
$strMoreStatusVars = 'متغيّرات حالة إضافية';
$strMoveTable = 'نقل جدول إلى (قاعدة بيانات<b>.</b>جدول):';
$strMoveTableOK = '%s جدول تم نقله إلى %s.';
$strMoveTableSameNames = 'لايمكن نقل الجدول إلى نفسه!';
$strMultilingual = 'متعدد اللغات';
$strMustSelectFile = 'يجب أن تحدد الملف الذي تريد أن تضيفه.';
$strMySQLCharset = 'شيفرة أحرف MySQL';
$strMySQLReloaded = 'تم إعادة تحميل MySQL بنجاح.';
$strMySQLSaid = 'MySQL قال: ';
$strMySQLServerProcess = 'MySQL %pma_s1%  على المزود %pma_s2% -  المستخدم : %pma_s3%';
$strMySQLShowProcess = 'عرض العمليات';
$strMySQLShowStatus = 'عرض حالة المزود MySQL';
$strMySQLShowVars ='عرض متغيرات المزود MySQL';

$strName = 'الإسم';
$strNext = 'التالي';
$strNo = 'لا';
$strNoDatabases = 'لايوجد قواعد بيانات';
$strNoDatabasesSelected = 'لا قواعد بيانات محددة';
$strNoDescription = 'بدون وصف';
$strNoDropDatabases = 'معطل "حذف قاعدة بيانات"الأمر ';
$strNoExplain = 'تخطّي شرح SQL';
$strNoFrames = 'phpMyAdmin أكثر تفهماً مع مستعرض <b>الإطارات</b>.';
$strNoIndex = 'فهرس غير معرف!';
$strNoIndexPartsDefined = 'إجزاء الفهرسه غير معرفه!';
$strNoModification = 'لا تغييرات';
$strNoOptions = 'هذا التنسيق ليس له أي خيارات';
$strNoPassword = 'لا كلمة سر';
$strNoPermission = 'خادأ£ الوب ليس لديه صلاحية لحفظ الملف %s.';
$strNoPhp = 'بدون شيفرة PHP';
$strNoPrivileges = 'إمتياز غير موجود';
$strNoQuery = 'ليست إستعلام SQL!';
$strNoRights = 'ليس لديك الحقوق الكافيه بأن تكون هنا الآن!';
$strNoSpace = 'لا يوجد مساحة كافية لحفظ الملف %s.';
$strNoTablesFound = 'لايوجد جداول متوفره في قاعدة البيانات هذه!.';
$strNoUsersFound = 'المستخدم(ـين) لم يتم إيجادهم.';
$strNoValidateSQL = 'تخطّي التأكّد من SQL';
$strNone = 'لاشئ';
$strNotNumber = 'هذا ليس رقم!';
$strNotOK = 'ليس صالحاً';
$strNotSet = 'الجدول <b>%s</b> غير موجود أو محدد في %s';
$strNull = 'خالي';
$strNumSearchResultsInTable = '%s مطابقة في الجدول <i>%s</i>';
$strNumSearchResultsTotal = '<b>المجموع:</b> <i>%s</i>مطابقة';
$strNumTables = 'جداول';

$strOK = 'موافق';
$strOftenQuotation = 'غالباً علامات الإقتباس. إختياري يعني بأن الحقول  char و varchar ترفق بـ " ".';
$strOperations = 'عمليّات';
$strOptimizeTable = 'ضغط الجدول';
$strOptionalControls = 'إختياري. التحكم في كيفية كتابة أو قراءة الأحرف أو الجمل الخاصه.';
$strOptionally = 'إختياري';
$strOr = 'أو';
$strOverhead = 'الفوقي';
$strOverwriteExisting = 'خزن على الملفات الموجودة أصلاً';

$strPHP40203 = 'أنت تستخدم الإصدار 4.2.3 من PHP والذي يحتوي على خلّل خطير في التعامل مع النصوص ثنائية البايت (mbstring). أنظر في تقرير خلل PHP رقم 19404. لا ينصح باستخدام هذه النسخة من PHP مع phpMyAdmin.';
$strPHPVersion = ' PHP إصدارة';
$strPageNumber = 'صفحة رقم:';
$strPaperSize = 'حجم الورق';
$strPartialText = 'نصوص جزئيه';
$strPassword = 'كلمة السر';
$strPasswordChanged = 'تم تغيير كلمة المرور لـ %s بنجاح.';
$strPasswordEmpty = 'كلمة السر فارغة !';
$strPasswordNotSame = 'كلمتا السر غير متشابهتان !';
$strPdfDbSchema = 'بناء قاعدة البيانات "%s" - الصفحة %s';
$strPdfInvalidTblName = 'الجدول "%s" غير موجود!';
$strPdfNoTables = 'لا يوجد جداول';
$strPerHour = 'لكل ساعة';
$strPerMinute = 'لكل دقيقة';
$strPerSecond = 'لكل ثانية';
$strPhoneBook = 'دفتر الهاتف';
$strPhp = 'أنشئ شيفرة PHP';
$strPmaDocumentation = 'مستندات وثائقيه لـ phpMyAdmin (بالإنجليزية)';
$strPmaUriError = 'المتغير <span dir="ltr"><tt>$cfg[\'PmaAbsoluteUri\']</tt></span> يجب تعديله في ملف الكوفيك !';
$strPortrait = 'طول الصفحة';
$strPos1 = 'بداية';
$strPrevious = 'سابق';
$strPrimary = 'أساسي';
$strPrimaryKeyHasBeenDropped = 'لقد تم حذف المفتاح الأساسي';
$strPrimaryKeyName = 'إسم المفتاح الأساسي يجب أن يكون أساسي... PRIMARY!';
$strPrimaryKeyWarning = '("الأساسي" <b>يجب</b> يجب أن يكون الأسم <b>وأيضاً فقط</b> المفتاح الأساسي!)';
$strPrint = 'إطبع';
$strPrintView = 'عرض نسخة للطباعة';
$strPrintViewFull = 'عرض الطباعة (مع النصوص الكاملة).';
$strPrivDescAllPrivileges = 'يتضمّن كل الصلاحيّات عدا GRANT.';
$strPrivDescAlter = 'يسمح بتعديل بناء الجداول الموجودة مسبقاً.';
$strPrivDescCreateDb = 'يسمح بإنشاء قواعد بيانات وجداول جديدة.';
$strPrivDescCreateTbl = 'يسمح بإنشاء جداول جديدة.';
$strPrivDescCreateTmpTable = 'يسمح بإنشاء جداول مؤقّتة.';
$strPrivDescDelete = 'يسمح بحذف البيانات.';
$strPrivDescDropDb = 'يسمح بحذف قواعد البيانات.';
$strPrivDescDropTbl = 'يسمح بحذف الجداول.';
$strPrivDescExecute = 'يسمح بتشغيل الإجراءات المخزّنة )stored procedures(، ليس له أي تأثير في هذه النسخة من خادم MySQL.';
$strPrivDescFile = 'يسمح باستيراد وتصدير البيانات من وإلى الملفّات.';
$strPrivDescGrant = 'يسمح بإضافة المستخدمين والصلاحيات دون إعادة قراءة جداول الصلاحيات.';
$strPrivDescIndex = 'يسمح بإنشاء وحذف الفهارس.';
$strPrivDescInsert = 'يسمح بإضافة واستبدال البيانات.';
$strPrivDescLockTables = 'يسمح بقفل الجداول للعمليّة الحاليّة.';
$strPrivDescMaxConnections = 'يحدّ من عدد الاتصالات الجديدة التي يمكن للمستخدم فتحها بكل ساعة.';
$strPrivDescMaxQuestions = 'يحدّ عدد الاستعلامات التي يستطيع المستخدم إرسالها إلى الخادم بكل ساعة.';
$strPrivDescMaxUpdates = 'يحدّ عدد الأوامر التي ينفذها المستخدم بكل ساعة، والتي تغير أي جدول أو قاعدة بيانات.';
$strPrivDescProcess3 = 'يسمح بإيقاف عمليّات المستخدمين الأخرين.';
$strPrivDescProcess4 = 'يسمح بعرض الاستعلام بالكامل في سرد العمليات.';
$strPrivDescReferences = 'ليس له أي تأثير في نسخة MySQL الحاليّة.';
$strPrivDescReload = 'يسمح بإعادة تحميل إعدادات الخادم وتفريغ كاش الخادم.';
$strPrivDescReplClient = 'يعطي الحق للمستخدم بالسؤال عن مكان وجود slaves/masters.';
$strPrivDescReplSlave = 'مطلوب لتوابع لاستنساخ.';
$strPrivDescSelect = 'يسمح بقراءة البيانات.';
$strPrivDescShowDb = 'يسمح بالوصول لقائمة أسماء جميع قواعد البيانات.';
$strPrivDescShutdown = 'يسمح بإيقاف عمل الخادم.';
$strPrivDescSuper = 'يسمح بالاتصال، حتى لو وصل حدّ عدد الاتصالات للأقصى.، مطلوب للمهام الإدارية كضبط الإعدادات العامّة other users.';
$strPrivDescUpdate = 'يسمح بتعديل البيانات.';
$strPrivDescUsage = 'لا صلاحيات.';
$strPrivileges = 'الإمتيازات';
$strPrivilegesReloaded = 'تم إعادة قراءة الصلاحيات بنجاح.';
$strProcesslist = 'سرد العمليّات';
$strPutColNames = 'ضع أسماء الحقول في السطر الأول';

$strQBE = 'إستعلام بواسطة مثال';
$strQBEDel = 'Del';
$strQBEIns = 'Ins';
$strQueryFrame = 'نافذة الاستعلام';
$strQueryOnDb = 'في قاعدة البيانات SQL-إستعلام <b>%s</b>:';
$strQuerySQLHistory = 'نصوص SQL سابقة';
$strQueryStatistics = '<b>إحصائيات الاستعلام</b>: %s استعلام أرسل إلى الخادم منذ تشغيله.';
$strQueryTime = 'استغرف الاستعلام %01.4f ثانية';
$strQueryType = 'نوع الاستعلام';
$strQueryWindowLock = 'لا تخزن على هذا الاستعلام من خارج النافذة';

$strReType = 'أعد كتابه';
$strReceived = 'استُلِم';
$strRecords = 'التسجيلات';
$strReferentialIntegrity = 'تحديد التكامل المرجعي:';
$strRelationNotWorking = 'تمّ تعطيل المزايا الإضافية للعمل بالجداول المترابطة. لمعرفة السبب إضغط %sهنا%s.';
$strRelationView = 'عرض الروابط';
$strRelationalSchema = 'بناء الإرتباطات';
$strRelations = 'الروابط';
$strReloadFailed = ' إعادة تحميل خاطئهMySQL.';
$strReloadMySQL = 'إعادة تحميل MySQL';
$strReloadingThePrivileges = 'قيد إعادة قراءة الصلاحيات.';
$strRemoveSelectedUsers = 'إحذف المستخدمين المحددين';
$strRenameTable = 'تغيير إسم جدول إلى';
$strRenameTableOK = 'تم تغيير إسمهم إلى %s  جدول%s';
$strRepairTable = 'إصلاح الجدول';
$strReplace = 'إستبدال';
$strReplaceNULLBy = 'استبدل NULL بـ';
$strReplaceTable = 'إستبدال بيانات الجدول بالملف';
$strReset = 'إلغاء';
$strResourceLimits = 'حدود المصادر';
$strRevoke = 'إبطال';
$strRevokeAndDelete = 'استرجع كل الصلاحيات الفعالة من المستخدمين ثم احذفهم بعد ذلك.';
$strRevokeAndDeleteDescr = 'سوف تبقى الصلاحية USAGE لدى المستخدمين حتى يتم إعادة قراءة الصلاحيات.';
$strRevokeMessage = 'لقد أبطلت الأمتيازات لـ %s';
$strRowLength = 'طول الصف';
$strRowSize = ' مقاس الصف ';
$strRows = 'صفوف';
$strRowsFrom = 'صفوف تبدأ من';
$strRowsModeFlippedHorizontal = ')عناوين ملتفّة( أفقياً';
$strRowsModeHorizontal = 'أفقي';
$strRowsModeOptions = ' %s و إعادة الرؤوس بعد %s حقل';
$strRowsModeVertical = 'عمودي';
$strRowsStatistic = 'إحصائيات';
$strRunQuery = 'إرسال الإستعلام';
$strRunSQLQuery = 'تنفيذ إستعلام/إستعلامات SQL على قاعدة بيانات %s';
$strRunning = ' على المزود %s';
$strRussian = 'الروسية';

$strSQL = 'SQL';
$strSQLExportType = 'نوع التصدير';
$strSQLOptions = 'خيارات SQL';
$strSQLParserBugMessage = 'هناك احتمال أنك عثرت على خلل في مدققّ SQL. رجاءً اختبر استعلامك بدقّة، وتأكّد من أن علامات التنصيص صحيحة ومتطابقة. بعض أسباب الإخفاق الأخرى قد تكون أنك تحاول تحميل ملف يحتوي على بيانات غير نصّية خارج منطقة التنصيص. يمكنك أيضاً تجربة استعلامك بواسطة سطر أوامر MySQL. قد تساعدك رسالة خطأ خادم MySQL أدناه، إن كانت هناك واحدة، على تشخيص المشكلة. إن بقي هناك مشاكل أو إن أخفق المدقّق في حين نجح استخدام سطر الأوامر، رجاءً قلّص حجم استعلامك لاستعلام واحد يسبب المشكلة، وقم بإرسال تقرير خلل مع جزء البيانات في منطقة القصّ أدناه:';
$strSQLParserUserError = 'يبدو أن هناك خطأ في استعلام SQL. سوف تساعدك رسالة الخطأ من خادم MySQL أدناه في تشخيص المشكلة، إن كان هناك واحدة،.';
$strSQLQuery = 'إستعلام-SQL';
$strSQLResult = 'ناتج استعلام SQL';
$strSQPBugInvalidIdentifer = 'معرّف غير صالح';
$strSQPBugUnclosedQuote = 'علامة تنصيص غير مغلقة';
$strSQPBugUnknownPunctuation = 'نص تنقيط غير معروف';
$strSave = 'حفــظ';
$strSaveOnServer = 'إحفظ على الخادم في الدليل %s';
$strScaleFactorSmall = 'نسبة الحجم المحددة صغيرة جدا لملائمة المخطط في صفحة واحدة.';
$strSearch = 'إبحث';
$strSearchFormTitle = 'إبحث في قاعدة البيانات';
$strSearchInTables = 'داخل الجدول)الجداول(:';
$strSearchNeedle = 'الكلمات أو القيم المطلوب البحث عنها (wildcard: "%"):';
$strSearchOption1 = 'على الأقل أحد الكلمات';
$strSearchOption2 = 'كل الكلمات';
$strSearchOption3 = 'الجملة بالضبط';
$strSearchOption4 = 'كصيغة مطابقة';
$strSearchResultsFor = 'إبحث في النتائج عن "<i>%s</i>" %s:';
$strSearchType = 'إبحث:';
$strSecretRequired = 'يحتاج ملف الإعداد الآن إلى كلمة المرور السريّة.';
$strSelectADb = 'إختر قاعدة بيانات من القائمة';
$strSelectAll = 'تحديد الكل';
$strSelectFields = 'إختيار حقول (على الأقل واحد):';
$strSelectNumRows = 'في الإستعلام';
$strSelectTables = 'إختر الجداول';
$strSend = 'حفظ كملف';
$strSent = 'أُرسِل';
$strServer = 'خادم';
$strServerChoice = 'إختيار الخادم';
$strServerStatus = 'بيانات التشغيل';
$strServerStatusUptime = 'مضى على عمل خادم MySQL مدة %s. بدأ العمل في %s.';
$strServerTabProcesslist = 'معالَجات';
$strServerTabVariables = 'متغيّرات';
$strServerTrafficNotes = '<b>سيْر الخادم</b>: تظهر هذه الجداول إحصائيات سيْر بيانات الشبكة لهذا الخادم منذ تشغيله.';
$strServerVars = 'متغيّرات وأعدادات الخادم';
$strServerVersion = 'إصدارة المزود';
$strSessionValue = 'قيمة الجلسة';
$strSetEnumVal = 'إذا كان نوع الحقل هو "enum" أو "set", الرجاء إدخال القيم بإستخدام هذا التنسيق: \'a\',\'b\',\'c\'...<br />إذا كنت تحتاج بأن تضع علامة الشرطه المائله لليسار ("\") أو علامة الإقتباس الفرديه ("\'") فيما بين تلك القيم, إجعلها كشرطه مائله لليسار (مثلاً \'\\\\xyz\' أو \'a\\\'b\').';
$strShow = 'عرض';
$strShowAll = 'شاهد الكل';
$strShowColor = 'أظهر اللون';
$strShowDatadictAs = 'تنسيق قامون البيانات';
$strShowFullQueries = 'إعرض الاستعلامات كاملة';
$strShowGrid = 'أظهر تخطيط الجدول';
$strShowPHPInfo = 'عرض المعلومات المتعلقة ب  PHP';
$strShowTableDimension = 'إظهار أبعاد الجداول';
$strShowTables = 'شاهد الجدول';
$strShowThisQuery = ' عرض هذا الإستعلام هنا مرة أخرى ';
$strShowingRecords = 'مشاهدة السجلات ';
$strSimplifiedChinese = 'الصينية المبسطة';
$strSingly = '(فردي)';
$strSize = 'الحجم';
$strSort = 'تصنيف';
$strSortByKey = 'رتّب حسب المفتاح';
$strSpaceUsage = 'المساحة المستغلة';
$strSplitWordsWithSpace = 'الكلمات مفصولة بحرف مسافة (" ").';
$strStatCheckTime = 'التحقق الأخير';
$strStatCreateTime = 'الإنشاء';
$strStatUpdateTime = 'التحديث الأخير';
$strStatement = 'أوامر';
$strStatus = 'وضْع';
$strStrucCSV = 'بيانات CSV';
$strStrucData = 'البنية والبيانات';
$strStrucDrop = ' إضافة \'حذف جدول إذا كان موجودا\' في البداية';
$strStrucExcelCSV = 'بيانات CSV لبرنامج ميكروسوفت إكسل';
$strStrucOnly = 'البنية فقط';
$strStructPropose = 'اقترح بناء الجدول';
$strStructure = 'بناء';
$strSubmit = 'إرسال';
$strSuccess = 'الخاص بك تم تنفيذه بنجاح SQL-إستعلام';
$strSum = 'المجموع';
$strSwedish = 'السويدية';
$strSwitchToTable = 'بدّل إلى الجدول المنسوخ';

$strTable = 'الجدول ';
$strTableComments = 'تعليقات على الجدول';
$strTableEmpty = 'إسم الجدول فارغ!';
$strTableHasBeenDropped = 'جدول %s حُذفت';
$strTableHasBeenEmptied = 'جدول %s أُفرغت محتوياتها';
$strTableHasBeenFlushed = 'لقد تم إعادة تحميل الجدول %s  بنجاح';
$strTableMaintenance = 'صيانة الجدول';
$strTableOfContents = 'جدول المحتويات';
$strTableOptions = 'خيارات الجدول';
$strTableStructure = 'بنية الجدول';
$strTableType = 'نوع الجدول';
$strTables = '%s  جدول (جداول)';
$strTblPrivileges = 'صلاحيات خاصة بالجدول';
$strTextAreaLength = ' بسبب طوله,<br /> فمن المحتمل أن هذا الحقل غير قابل للتحرير ';
$strThai = 'التايلندية';
$strTheContent = 'لقد تم إدخال محتويات ملفك.';
$strTheContents = 'لقد تم إستبدال محتويات الجدول المحدد للصفوف بالمفتاح المميز أو الأساسي المماثل لهما بمحتويات الملف.';
$strTheTerminator = 'فاصل الحقول.';
$strThisHost = 'هذا المضيف';
$strThisNotDirectory = 'لم يكن هذا دليلاً';
$strThreadSuccessfullyKilled = 'تم إيقاف العمليّة %s بنجاح.';
$strTime = 'وقت';
$strToggleScratchboard = 'toggle scratchboard';
$strTotal = 'المجموع';
$strTotalUC = 'مجموع كلّي';
$strTraditionalChinese = 'الصينية التقليدية';
$strTraffic = 'بيانات سير';
$strTransformation_image_jpeg__inline = 'يظهر صورة مصغرة للضغط عليها، الخيارات:  العرض، الارتفاع بالبكسل )ويبقي التناسب الأصلي للحجم(.';
$strTransformation_image_jpeg__link = 'يظهر رابطاً لهذه الصورة (direct blob download, i.e.).';
$strTransformation_image_png__inline = 'إعرض صور/jpeg: بنفس السطر';
$strTransformation_text_plain__dateformat = 'يتطلّب TIME, TIMESTAMP أو DATETIME والتنسيق باستخدام تنسيق التاريخ المحلي الخاص بك. الخيار الأول هو التعديل )بالساعات) والذي سوف يضاف إلى timestamp )صفر بشكل افتراضي(. الخيار الثاني هو تنسيق تاريخ مختلف بناءً على المتغيرات المتوفرة لـPHP strftime().';
$strTransformation_text_plain__external = 'لينكس فقط: يشغّل تطبيقاً خارجياً و يقوم بتغذية بيانات الحقل عبر المدخل الافتراضي. يسترجع مخرجات التطبيق الافتراضية. القيمة الافتراضية هي Tidy، كي تطبع شيفرة نص HTML بشكل جميل. لأسباب أمنية، عليك أن تقوم بتعديل الملف libraries/transformations/text_plain__external.inc.php وإضافة الأدوات التي تريد أن تسمح لها بالعمل. الخيار الأول عند ذلك هو رقم البرنامج الذي تريد أن تستخدمه والخيار الثاني هو المتغيرات للبرنامج. سوف يقوم الخيار الثالث، إن حدد بقيمة 1، بتحويل المخرجات باستخدام htmlspecialchars() )القيمة الافتراضية 1(. متغير رابع، إن حدد بقيمة 1 سوف يضيف الصفة NOWRAP إلى الخلية الحاوية حتى يصبح المخرج بأكمله بدن إعادة تنسيق )القيمة الافتراضية 1(.';
$strTransformation_text_plain__formatted = 'يُبقي التنسيق الأصلي للحقل. لا يتم عمل أي Escaping.';
$strTransformation_text_plain__imagelink = 'تظهر صورة ورابط، يتحوي الحقل على إسم الملف، الخيار الأول هو سابقة مثل "http://domain.com/"، والخيار الثاني هو العرض بالبكسل، والثالث هو الارتفاع.';
$strTransformation_text_plain__link = 'تظهر رابطاً، الحقل يحتوي إسم الملف، والخيار الأول هو سابقة مثل "http://domain.com/"، والخيار الثاني هو العنوان للرابط.';
$strTransformation_text_plain__substr = 'يظهر فقط جزءً من النص. الخيار الأول يحدد مكان بدء ظهور النص )صفر بشكل افتراضي(. الخيار الثاني هو تعديل كمّ النص المسترجع. إن كان فارغاً، يسترجع كل النص الباقي. الخيار الثالث يعرف أي من الأحرف سوف تضاف إلى المخرجات عند استرجاع جزء من النص )... بشكل افتراضي(.';
$strTruncateQueries = 'إحذف الاستعلامات المعروضة';
$strTurkish = 'التركية';
$strType = 'النوع';

$strUkrainian = 'الأكرانية';
$strUncheckAll = 'إلغاء تحديد الكل';
$strUnicode = 'يونيكود';
$strUnique = 'مميز';
$strUnknown = 'غير معروفة';
$strUnselectAll = 'إلغاء تحديد الكل';
$strUpdComTab = 'رجاء راجع التوثيق لكيفية تحديث جدول Column_comments.';
$strUpdatePrivMessage = 'لقد جددت وحدثت الإمتيازات لـ %s.';
$strUpdateProfileMessage = 'لقد تم تجديد العرض الجانبي.';
$strUpdateQuery = 'تجديد إستعلام';
$strUpgrade = 'عليك التحديث إلى %s %s أو لاحقا.';
$strUsage = 'المساحة';
$strUseBackquotes = 'حماية أسماء الجداول و الحقول ب "`" ';
$strUseHostTable = 'استخدم الجدول المضيف';
$strUseTables = 'إستخدم الجدول';
$strUseTextField = 'استخدم حقل نصّ';
$strUseThisValue = 'استخدم هذه القيمة';
$strUser = 'المستخدم';
$strUserAlreadyExists = 'إسم المستخدم %s موجود مسبقاً!';
$strUserEmpty = 'إسم المستخدم فارغ!';
$strUserName = 'إسم المستخدم';
$strUserNotFound = 'المستخدم المحدد غير موجود في جدول الصلاحيات.';
$strUserOverview = 'معلومات المستخدم';
$strUsersDeleted = 'تم حذف المستخدمين المحددين بنجاح.';
$strUsersHavingAccessToDb = 'المستخدمين ذوي صلاحية الوصول إلى &quot;%s&quot;';

$strValidateSQL = 'التحقق من استعلام SQL';
$strValidatorError = 'لم يمكن تشغيل محقق SQL. الرجاء التأكد مما إذا كنت ثبّتْت إضافات PHP كما هو مشروح في %sالتوثيق%s.';
$strValue = 'القيمه';
$strVar = 'متغيّر';
$strViewDump = 'عرض بنية الجدول ';
$strViewDumpDB = 'عرض بنية قاعدة البيانات';
$strViewDumpDatabases = 'إعرض أو إحفظ بناء قواعد البيانات.';

$strWebServerUploadDirectory = 'دليل تحميل الملفات على خادم الشبكة';
$strWebServerUploadDirectoryError = 'الدليل الذي حددته لتحميل عملك لا يمكن الوصول إليه.';
$strWelcome = 'أهلاً بك في %s';
$strWestEuropean = 'أوروبا الغربية';
$strWildcard = 'حرف شامل';
$strWindowNotFound = 'لم يمكن تحديث نافذة المتصفح المستهدفة. يبدو أنك أغلقت الرئيسية أو أن مستعرضك يمنع التحديث عبر النوافذ بسبب إعدادات الأمان.';
$strWithChecked = ': على المحدد';
$strWritingCommentNotPossible = 'كتابة التعليق غير ممكن';
$strWritingRelationNotPossible = 'كتابة العلاقة غير ممكنة';
$strWrongUser = 'خطأ إسم المستخدم/كلمة السر. الدخول ممنوع.';

$strXML = 'XML';

$strYes = 'نعم';

$strZeroRemovesTheLimit = 'ملاحظة: تغيير هذه الخيارات للرقم 0 )صفر( يلغي الحدّ.';
$strZip = '"zipped" "مضغوط"';

$strGeorgian = 'Georgian';  //to translate
$strCzechSlovak = 'Czech-Slovak';  //to translate
$strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
$strMaximumSize = 'Maximum size: %s%s';  //to translate
$strConnectionError = 'Cannot connect: invalid settings.';  //to translate
$strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate
$strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';  //to translate
$strNeedPrimaryKey = 'You should define a primary key for this table.';  //to translate
$strIgnoreInserts = 'Use ignore inserts';  //to translate
$strAddIfNotExists = 'Add IF NOT EXISTS';  //to translate
$strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
$strRelationsForTable = 'RELATIONS FOR TABLE';  //to translate
$strAfterInsertSame = 'Go back to this page';  //to translate
$strRenameDatabaseOK = 'Database %s has been renamed to %s';  //to translate
$strDatabaseEmpty = 'The database name is empty!';  //to translate
$strDBRename = 'Rename database to';  //to translate
$strOperator = 'Operator';  //to translate
$strEncloseInTransaction = 'Enclose export in a transaction';  //to translate
$strCalendar = 'Calendar';  //to translate
$strRefresh = 'Refresh';  //to translate
$strDefragment = 'Defragment table';  //to translate
$strNoRowsSelected = 'No rows selected';  //to translate
$strSpanish = 'Spanish';  //to translate
$strStrucNativeExcel = 'Native MS Excel data';  //to translate
$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
$strServerNotResponding = 'The server is not responding';  //to translate
$strTheme = 'Theme / Style';  //to translate
$strTakeIt = 'take it';  //to translate
$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
$strIcelandic = 'Icelandic';  //to translate
$strLatvian = 'Latvian';  //to translate
$strPolish = 'Polish';  //to translate
$strRomanian = 'Romanian';  //to translate
$strSlovenian = 'Slovenian';  //to translate
$strTraditionalSpanish = 'Traditional Spanish';  //to translate
$strSlovak = 'Slovak';  //to translate
$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate
$strPersian = 'Persian';  //to translate
$strAddFields = 'Add %s field(s)';  //to translate
$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogEventType = 'Event type';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogInfo = 'Information';  //to translate
$strBinaryLog = 'Binary log';  //to translate
$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strDBCopy = 'Copy database to';  //to translate
$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
$strSwitchToDatabase = 'Switch to copied database';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strAfterInsertNext = 'Edit next row';  //to translate
$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strEngines = 'Engines';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
$strVersionInformation = 'Version information';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strRoutines = 'Routines';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate
$strGenerate = 'Generate';  //to translate
$strCopy = 'Copy';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
$strInvalidRowNumber = '%d is not valid row number.';  //to translate
$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
$strAndThen = 'and then';  //to translate
?>
